@@ -27,8 +27,11 @@ from telegram import TelegramObject
 class PassportElementError(TelegramObject):
     """Baseclass for the PassportElementError* classes.
 
+    This object represents an error in the Telegram Passport element which was submitted that
+    should be resolved by the user.
+
     Objects of this class are comparable in terms of equality. Two objects of this class are
-    considered equal, if their :attr:`source` and  :attr:`type`  are equal.
+    considered equal, if their :attr:`source` and :attr:`type` are equal.
 
     Args:
         source (:obj:`str`): Error source.
@@ -42,6 +45,9 @@ class PassportElementError(TelegramObject):
 
     """
 
+    # All subclasses of this class won't have _id_attrs in slots since it's added here.
+    __slots__ = ('message', 'source', 'type', '_id_attrs')
+
     def __init__(self, source: str, type: str, message: str, **_kwargs: Any):
         # Required
         self.source = str(source)
@@ -58,12 +64,12 @@ class PassportElementErrorDataField(PassportElementError):
 
     Objects of this class are comparable in terms of equality. Two objects of this class are
     considered equal, if their :attr:`source`, :attr:`type`, :attr:`field_name`, :attr:`data_hash`
-    and  :attr:`message`  are equal.
+    and :attr:`message` are equal.
 
     Args:
         type (:obj:`str`): The section of the user's Telegram Passport which has the error, one of
-            "personal_details", "passport", "driver_license", "identity_card", "internal_passport",
-            "address".
+            ``"personal_details"``, ``"passport"``, ``"driver_license"``, ``"identity_card"``,
+            ``"internal_passport"``, ``"address"``.
         field_name (:obj:`str`): Name of the data field which has the error.
         data_hash (:obj:`str`): Base64-encoded data hash.
         message (:obj:`str`): Error message.
@@ -71,14 +77,16 @@ class PassportElementErrorDataField(PassportElementError):
 
     Attributes:
         type (:obj:`str`): The section of the user's Telegram Passport which has the error, one of
-            "personal_details", "passport", "driver_license", "identity_card", "internal_passport",
-            "address".
+            ``"personal_details"``, ``"passport"``, ``"driver_license"``, ``"identity_card"``,
+            ``"internal_passport"``, ``"address"``.
         field_name (:obj:`str`): Name of the data field which has the error.
         data_hash (:obj:`str`): Base64-encoded data hash.
         message (:obj:`str`): Error message.
 
     """
 
+    __slots__ = ('data_hash', 'field_name')
+
     def __init__(self, type: str, field_name: str, data_hash: str, message: str, **_kwargs: Any):
         # Required
         super().__init__('data', type, message)
@@ -94,26 +102,28 @@ class PassportElementErrorFile(PassportElementError):
     the document scan changes.
 
     Objects of this class are comparable in terms of equality. Two objects of this class are
-    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hash`, :attr:`data_hash`
-    and  :attr:`message`  are equal.
+    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hash`, and
+    :attr:`message` are equal.
 
     Args:
         type (:obj:`str`): The section of the user's Telegram Passport which has the issue, one of
-            "utility_bill", "bank_statement", "rental_agreement", "passport_registration",
-            "temporary_registration".
+            ``"utility_bill"``, ``"bank_statement"``, ``"rental_agreement"``,
+            ``"passport_registration"``, ``"temporary_registration"``.
         file_hash (:obj:`str`): Base64-encoded file hash.
         message (:obj:`str`): Error message.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
     Attributes:
         type (:obj:`str`): The section of the user's Telegram Passport which has the issue, one of
-            "utility_bill", "bank_statement", "rental_agreement", "passport_registration",
-            "temporary_registration".
+            ``"utility_bill"``, ``"bank_statement"``, ``"rental_agreement"``,
+            ``"passport_registration"``, ``"temporary_registration"``.
         file_hash (:obj:`str`): Base64-encoded file hash.
         message (:obj:`str`): Error message.
 
     """
 
+    __slots__ = ('file_hash',)
+
     def __init__(self, type: str, file_hash: str, message: str, **_kwargs: Any):
         # Required
         super().__init__('file', type, message)
@@ -124,30 +134,32 @@ class PassportElementErrorFile(PassportElementError):
 
 class PassportElementErrorFiles(PassportElementError):
     """
-    Represents an issue with a list of scans. The error is considered resolved when the file with
-    the document scan changes.
+    Represents an issue with a list of scans. The error is considered resolved when the list of
+    files with the document scans changes.
 
     Objects of this class are comparable in terms of equality. Two objects of this class are
-    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hashes`, :attr:`data_hash`
-    and  :attr:`message`  are equal.
+    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hashes`, and
+    :attr:`message` are equal.
 
     Args:
         type (:obj:`str`): The section of the user's Telegram Passport which has the issue, one of
-            "utility_bill", "bank_statement", "rental_agreement", "passport_registration",
-            "temporary_registration".
+            ``"utility_bill"``, ``"bank_statement"``, ``"rental_agreement"``,
+            ``"passport_registration"``, ``"temporary_registration"``.
         file_hashes (List[:obj:`str`]): List of base64-encoded file hashes.
         message (:obj:`str`): Error message.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
     Attributes:
         type (:obj:`str`): The section of the user's Telegram Passport which has the issue, one of
-            "utility_bill", "bank_statement", "rental_agreement", "passport_registration",
-            "temporary_registration".
+            ``"utility_bill"``, ``"bank_statement"``, ``"rental_agreement"``,
+            ``"passport_registration"``, ``"temporary_registration"``.
         file_hashes (List[:obj:`str`]): List of base64-encoded file hashes.
         message (:obj:`str`): Error message.
 
     """
 
+    __slots__ = ('file_hashes',)
+
     def __init__(self, type: str, file_hashes: str, message: str, **_kwargs: Any):
         # Required
         super().__init__('files', type, message)
@@ -162,12 +174,12 @@ class PassportElementErrorFrontSide(PassportElementError):
     the file with the front side of the document changes.
 
     Objects of this class are comparable in terms of equality. Two objects of this class are
-    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hash`, :attr:`data_hash`
-    and  :attr:`message`  are equal.
+    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hash`, and
+    :attr:`message` are equal.
 
     Args:
         type (:obj:`str`): The section of the user's Telegram Passport which has the issue, one of
-            "passport", "driver_license", "identity_card", "internal_passport".
+            ``"passport"``, ``"driver_license"``, ``"identity_card"``, ``"internal_passport"``.
         file_hash (:obj:`str`): Base64-encoded hash of the file with the front side of the
             document.
         message (:obj:`str`): Error message.
@@ -175,13 +187,15 @@ class PassportElementErrorFrontSide(PassportElementError):
 
     Attributes:
         type (:obj:`str`): The section of the user's Telegram Passport which has the issue, one of
-            "passport", "driver_license", "identity_card", "internal_passport".
+            ``"passport"``, ``"driver_license"``, ``"identity_card"``, ``"internal_passport"``.
         file_hash (:obj:`str`): Base64-encoded hash of the file with the front side of the
             document.
         message (:obj:`str`): Error message.
 
     """
 
+    __slots__ = ('file_hash',)
+
     def __init__(self, type: str, file_hash: str, message: str, **_kwargs: Any):
         # Required
         super().__init__('front_side', type, message)
@@ -192,16 +206,16 @@ class PassportElementErrorFrontSide(PassportElementError):
 
 class PassportElementErrorReverseSide(PassportElementError):
     """
-    Represents an issue with the front side of a document. The error is considered resolved when
+    Represents an issue with the reverse side of a document. The error is considered resolved when
     the file with the reverse side of the document changes.
 
     Objects of this class are comparable in terms of equality. Two objects of this class are
-    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hash`, :attr:`data_hash`
-    and  :attr:`message`  are equal.
+    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hash`, and
+    :attr:`message` are equal.
 
     Args:
         type (:obj:`str`): The section of the user's Telegram Passport which has the issue, one of
-            "driver_license", "identity_card".
+            ``"driver_license"``, ``"identity_card"``.
         file_hash (:obj:`str`): Base64-encoded hash of the file with the reverse side of the
             document.
         message (:obj:`str`): Error message.
@@ -209,13 +223,15 @@ class PassportElementErrorReverseSide(PassportElementError):
 
     Attributes:
         type (:obj:`str`): The section of the user's Telegram Passport which has the issue, one of
-            "passport", "driver_license", "identity_card", "internal_passport".
+            ``"driver_license"``, ``"identity_card"``.
         file_hash (:obj:`str`): Base64-encoded hash of the file with the reverse side of the
             document.
         message (:obj:`str`): Error message.
 
     """
 
+    __slots__ = ('file_hash',)
+
     def __init__(self, type: str, file_hash: str, message: str, **_kwargs: Any):
         # Required
         super().__init__('reverse_side', type, message)
@@ -230,24 +246,26 @@ class PassportElementErrorSelfie(PassportElementError):
     the file with the selfie changes.
 
     Objects of this class are comparable in terms of equality. Two objects of this class are
-    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hash`, :attr:`data_hash`
-    and  :attr:`message`  are equal.
+    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hash`, and
+    :attr:`message` are equal.
 
     Args:
         type (:obj:`str`): The section of the user's Telegram Passport which has the issue, one of
-            "passport", "driver_license", "identity_card", "internal_passport".
+            ``"passport"``, ``"driver_license"``, ``"identity_card"``, ``"internal_passport"``.
         file_hash (:obj:`str`): Base64-encoded hash of the file with the selfie.
         message (:obj:`str`): Error message.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
     Attributes:
         type (:obj:`str`): The section of the user's Telegram Passport which has the issue, one of
-            "passport", "driver_license", "identity_card", "internal_passport".
+            ``"passport"``, ``"driver_license"``, ``"identity_card"``, ``"internal_passport"``.
         file_hash (:obj:`str`): Base64-encoded hash of the file with the selfie.
         message (:obj:`str`): Error message.
 
     """
 
+    __slots__ = ('file_hash',)
+
     def __init__(self, type: str, file_hash: str, message: str, **_kwargs: Any):
         # Required
         super().__init__('selfie', type, message)
@@ -262,28 +280,30 @@ class PassportElementErrorTranslationFile(PassportElementError):
     The error is considered resolved when the file changes.
 
     Objects of this class are comparable in terms of equality. Two objects of this class are
-    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hash`, :attr:`data_hash`
-    and  :attr:`message`  are equal.
+    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hash`, and
+    :attr:`message` are equal.
 
     Args:
         type (:obj:`str`): Type of element of the user's Telegram Passport which has the issue,
-            one of "passport", "driver_license", "identity_card", "internal_passport",
-            "utility_bill", "bank_statement", "rental_agreement", "passport_registration",
-            "temporary_registration".
+            one of ``"passport"``, ``"driver_license"``, ``"identity_card"``,
+            ``"internal_passport"``, ``"utility_bill"``, ``"bank_statement"``,
+            ``"rental_agreement"``, ``"passport_registration"``, ``"temporary_registration"``.
         file_hash (:obj:`str`): Base64-encoded hash of the file.
         message (:obj:`str`): Error message.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
     Attributes:
         type (:obj:`str`): Type of element of the user's Telegram Passport which has the issue,
-            one of "passport", "driver_license", "identity_card", "internal_passport",
-            "utility_bill", "bank_statement", "rental_agreement", "passport_registration",
-            "temporary_registration".
+            one of ``"passport"``, ``"driver_license"``, ``"identity_card"``,
+            ``"internal_passport"``, ``"utility_bill"``, ``"bank_statement"``,
+            ``"rental_agreement"``, ``"passport_registration"``, ``"temporary_registration"``.
         file_hash (:obj:`str`): Base64-encoded hash of the file.
         message (:obj:`str`): Error message.
 
     """
 
+    __slots__ = ('file_hash',)
+
     def __init__(self, type: str, file_hash: str, message: str, **_kwargs: Any):
         # Required
         super().__init__('translation_file', type, message)
@@ -295,31 +315,33 @@ class PassportElementErrorTranslationFile(PassportElementError):
 class PassportElementErrorTranslationFiles(PassportElementError):
     """
     Represents an issue with the translated version of a document. The error is considered
-    resolved when a file with the document translation change.
+    resolved when a file with the document translation changes.
 
     Objects of this class are comparable in terms of equality. Two objects of this class are
-    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hashes`, :attr:`data_hash`
-    and  :attr:`message`  are equal.
+    considered equal, if their :attr:`source`, :attr:`type`, :attr:`file_hashes`, and
+    :attr:`message` are equal.
 
     Args:
         type (:obj:`str`): Type of element of the user's Telegram Passport which has the issue,
-            one of "passport", "driver_license", "identity_card", "internal_passport",
-            "utility_bill", "bank_statement", "rental_agreement", "passport_registration",
-            "temporary_registration"
+            one of ``"passport"``, ``"driver_license"``, ``"identity_card"``,
+            ``"internal_passport"``, ``"utility_bill"``, ``"bank_statement"``,
+            ``"rental_agreement"``, ``"passport_registration"``, ``"temporary_registration"``.
         file_hashes (List[:obj:`str`]): List of base64-encoded file hashes.
         message (:obj:`str`): Error message.
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
     Attributes:
         type (:obj:`str`): Type of element of the user's Telegram Passport which has the issue,
-            one of "passport", "driver_license", "identity_card", "internal_passport",
-            "utility_bill", "bank_statement", "rental_agreement", "passport_registration",
-            "temporary_registration"
+            one of ``"passport"``, ``"driver_license"``, ``"identity_card"``,
+            ``"internal_passport"``, ``"utility_bill"``, ``"bank_statement"``,
+            ``"rental_agreement"``, ``"passport_registration"``, ``"temporary_registration"``.
         file_hashes (List[:obj:`str`]): List of base64-encoded file hashes.
         message (:obj:`str`): Error message.
 
     """
 
+    __slots__ = ('file_hashes',)
+
     def __init__(self, type: str, file_hashes: str, message: str, **_kwargs: Any):
         # Required
         super().__init__('translation_files', type, message)
@@ -335,7 +357,7 @@ class PassportElementErrorUnspecified(PassportElementError):
 
     Objects of this class are comparable in terms of equality. Two objects of this class are
     considered equal, if their :attr:`source`, :attr:`type`, :attr:`element_hash`,
-    :attr:`data_hash` and  :attr:`message`  are equal.
+    and :attr:`message` are equal.
 
     Args:
         type (:obj:`str`): Type of element of the user's Telegram Passport which has the issue.
@@ -350,6 +372,8 @@ class PassportElementErrorUnspecified(PassportElementError):
 
     """
 
+    __slots__ = ('element_hash',)
+
     def __init__(self, type: str, element_hash: str, message: str, **_kwargs: Any):
         # Required
         super().__init__('unspecified', type, message)
